# solo_server/commands/init.py

import os
import shutil
from solo_server import utils

def handle_command(args):
    print("Welcome to Solo Server Project Initialization!")
    project_name = input("Enter your project name (default: my_project): ") or "my_project"

    # Check if the directory exists
    if os.path.exists(project_name):
        overwrite = input(f"Directory '{project_name}' already exists. Overwrite? (y/n): ")
        if overwrite.lower() != 'y':
            print("Project initialization canceled.")
            return
        else:
            shutil.rmtree(project_name)

    # Choose template
    templates_dir = utils.get_templates_dir()
    templates = utils.get_available_templates(templates_dir)
    print("Available templates:")
    for idx, template in enumerate(templates):
        print(f"{idx + 1}. {template}")
    template_choice = input("Select a template by number (default: 1): ") or "1"
    template_idx = int(template_choice) - 1
    template_name = templates[template_idx]

    # Copy template
    template_dir = os.path.join(templates_dir, template_name)
    shutil.copytree(template_dir, project_name)

    print(f"Project '{project_name}' initialized with template '{template_name}'.")



# solo_server/cli.py

import argparse
from solo_server.commands import init

def main():
    parser = argparse.ArgumentParser(description='Solo Server CLI')
    subparsers = parser.add_subparsers(dest='command')

    # Init command
    subparsers.add_parser('init', help='Initialize a new project')

    args = parser.parse_args()

    if args.command == 'init':
        init.handle_command(args)
    else:
        parser.print_help()

if __name__ == '__main__':
    main()



# solo_server/utils.py

import os

def get_templates_dir():
    current_dir = os.path.dirname(os.path.abspath(__file__))
    templates_dir = os.path.join(current_dir, 'templates')
    return templates_dir

def get_available_templates(templates_dir):
    templates = [name for name in os.listdir(templates_dir)
                 if os.path.isdir(os.path.join(templates_dir, name))]
    return templates



from setuptools import setup, find_packages

setup(
    name="solo-server",
    version="0.1.1",
    packages=find_packages(),
    include_package_data=True,
    install_requires=[
        "typer",
        "GPUtil",
        "psutil",
        "tqdm",
        "requests",
        "argparse"  # Added this as it's used in cli.py
    ],
    entry_points={
        "console_scripts": [
            "solo-server = solo_server.cli:main",  # Updated this line
        ],
    },
    author="Dhruv Diddi",
    author_email="dhruv.diddi@gmail.com",
    description="Simple server to manage compound AI.",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    url="https://github.com/AIEngineersDev/solo-server",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)